class MBuffer:
    def __init__(self,path,tags={}):
        self.path = path
        self.file = open(path,'a+')
        self.current = tags
        for line in self.file.read().splitlines():
            line = line.split('=')
            self.current[line[0]] = '='.join(line[1:])
            
    def gettag(self,tag_name):
        return self.current[tag_name]
    
    def rawtags(self):
        return self.current
    
    def settag(self,tag_name,tag_string):
        self.current[tag_name] = str(tag_string)
        
    def save(self,path):
        raw = ''
        for tag_name in self.current:
            raw += '%s=%s\n' % (tag_name,self.current[tag_name])
            
    def updatetags(self,new_tag_dict):
        self.current = new_tag_dict


from setuptools import setup

setup(name='ax-tools',
      version='0.1',
      description='Tools for Axyl AX System',
      url='http://github.com/Omega0x013/ax-tools',
      author='Alexander Bielby',
      author_email='xanderbielby@gmail.com',
      license='GNU GPLv3',
      packages=['axm'],
      zip_safe=False)